*       ANNIE - Simulated Annealing Magwalking 
*	AMMONIUM CHLORIDE CLUSTER SIMULATION PROGRAM
*       by Robert Q. Topper and Isaac Markus
*	Originally based on MAGGIE 4.0 by Denise Bergin, Paul Sweeney and RQT
*
*	4.7 updated pi, k_B, Bohr radius to latest values and propagared k_b as a new variable
*       kB*Temp is precalculated as KBTEMP 
*       4.7.1 maximum number of atoms is now 2000 instead of 500
*       and all REAL variables are now either DOUBLE PRECISION or REAL*8
*      Changed some of the DO loop markers to avoid confusion (but not all)
*       Added error check for max number of atoms


          CHARACTER*80 ANNIEVERSION
 	  INTEGER NATOM, NTEETH
	  INTEGER NN, NMOLECULES
	  INTEGER NCL
	  CHARACTER *2 SPECIES(3)  ! 1=N, 2 = X, 3=H
          DOUBLE PRECISION SPECIESMASS(3) ! 1=N, 2 = X, 3=H
	  DOUBLE PRECISION LOCALE(2000,4), TEMP(2000,4), TOOTHTOP(100)
	  INTEGER J
	  INTEGER ISEED
	  INTEGER MARKER1
	  INTEGER MARKER2
	  INTEGER REJECTS, NACCEPTS
	  INTEGER MAXREJECT
	  DOUBLE PRECISION X,Y,Z,BTOA
	  DOUBLE PRECISION SIZE
	  DOUBLE PRECISION DIST
	  DOUBLE PRECISION PI,KB, STEPSIZE, STEP, MAGSTEPPROB
	  DOUBLE PRECISION R
	  DOUBLE PRECISION XX,YY,ZZ,XSTEP,YSTEP,ZSTEP
	  DOUBLE PRECISION DX1, DX2, DX3, DX4
	  DOUBLE PRECISION DY1, DY2, DY3, DY4
	  DOUBLE PRECISION DZ1, DZ2, DZ3, DZ4
	  DOUBLE PRECISION PHI
	  DOUBLE PRECISION Q1,Q2,Q3,ALPHA11,ALPHA12,ALPHA13,ALPHA22, ALPHA23, ALPHA33
	  DOUBLE PRECISION A11,A12,A13,A22,A23,A33,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33
	  DOUBLE PRECISION ACCEPT_RATIO
	  DOUBLE PRECISION THETA, MAXANGLE, MAGROT
* 	UO and UNEWM are new variables for calcualting the potential before and after moving and atom
	  DOUBLE PRECISION U, KJ, UNEW, UO, UNEWM, CU,TU,RU,UTOTAL,UAVG,USQTOTAL,USQAVG,CV
	  INTEGER NSPOT, HSPOT, CLSPOT, PICKED, NTEMPS, NTHTEMP,INCMORE
	  DOUBLE PRECISION DELTEMP	
	  DOUBLE PRECISION DU, BOLTCOND, TEMPKEL, RC, TEMP1
	  DOUBLE PRECISION XSI,COUNTTEMPS
	  INTEGER MONTES,INPUT,COUNT
	  INTEGER IMOVIE
          INTEGER MONTEMULTIPLIER, MONTESTEPS
	  DOUBLE PRECISION XC,YC,ZC
	  DOUBLE PRECISION MASSX
          DOUBLE PRECISION ALPHAUPPERDEC
          DOUBLE PRECISION KBTEMP

*******	variables for nightran2.f ***********************************************	
	  PARAMETER (IVEC=1)
	  REAL*8 RN(IVEC)
      CHARACTER*80 OUTFILE(100), TEMPSFILE, TEXTFILE
********************************************************************************
      ANNIEVERSION='This is Annie 4.7.1'
	  NACCEPTS=0
	  REJECTS=0
	  U = 0.0
	  UNEW = 0.0
	  PI = 3.1415926535
	  BTOA = 0.529177210903	!bohrs to angstroms conversion
	  KB = 3.166812E-6  !hartrees/K  - according to 2018 CODATA

*********************************************************************************
* 	Opens Both the Input and Parameter Files
*   Unit 11 (runpars_in.txt) is the general input parameter file
*	Unit 13 (potpars_in.txt) contains the constants for the potential
*               energy function used in SUBROUTINE ENERGY
*   Unit 15 (final.xyz) is the final structure after a MC calc
*	Unit 16 is the compilation of structures for each temperature
*   Unit 17 is the movie file (movie.xyz). Only generated if IMOVIE is nonzero.
*   Unit 20 has the temperature as a function of the number of runs, as well
*                as the final energy at each temperature.
*   Unit 26 (usually something like output.txt) has various runtime data.

*	CONSTANTS READ IN
*********************************************************************************
	
*	GENERAL PARAMETERS
	  OPEN(11, file = 'runpars_in.txt')
	
	  READ(11,*)TEXTFILE
      READ(11,*)NN
	  READ(11,*)RC
	  READ(11,*)NCL
	  NATOM=5*NN+NCL
	  READ(11,*)SPECIES(1) ! 1=N, 2 = X, 3=H
	  READ(11,*)SPECIES(2)
	  READ(11,*)SPECIES(3)
	  READ(11,*)ISEED
	  READ(11,*)SIZE
	  READ(11,*)MAXREJECT
      READ(11,*)R
      READ(11,*)STEPSIZE
      READ(11,*)MAGSTEPPROB
      READ(11,*)MAXANGLE
      READ(11,*)MAGROT
      READ(11,*)TEMP1
      READ(11,*)NTEMPS
      READ(11,*)INCMORE
      READ(11,*)MONTES
      READ(11,*)TEMPSFILE
      READ(11,*)IMOVIE
      READ(11,*)MONTEMULTIPLIER
      READ(11,*)ALPHAUPPERDEC
      READ(11,*)NTEETH
      DO I=1,NTEETH
       READ(11,*)OUTFILE(I)
      END DO
      CLOSE (11)
      INPUT=1
*       
      IF (NATOM.GT.2000) THEN
          WRITE(6,*)'The number of atoms must be less than 2000.'
          STOP
      END IF
*          
      OPEN(26, file=TEXTFILE)
	  WRITE(26,*)ANNIEVERSION
	  IF (IMOVIE.NE.0) THEN  
	   OPEN(17, file = "MOVIE.xyz")
	  END IF  
*	PARAMETERS FOR POTENTIAL ENERGY FUNCTION
	  OPEN(13, file = 'potpars_in.txt')
*    1=N, 2=X, 3=H
	  READ(13,*)Q1 
	  READ(13,*)Q2
	  READ(13,*)Q3
	  READ(13,*)A11
	  READ(13,*)ALPHA11
	  READ(13,*)C11
	  READ(13,*)D11	
	  READ(13,*)A12
	  READ(13,*)ALPHA12
	  READ(13,*)C12
	  READ(13,*)D12	
	  READ(13,*)A13
	  READ(13,*)ALPHA13
	  READ(13,*)C13
	  READ(13,*)D13
	  READ(13,*)A22
	  READ(13,*)ALPHA22
	  READ(13,*)C22
	  READ(13,*)D22
	  READ(13,*)A23
	  READ(13,*)ALPHA23
	  READ(13,*)C23
	  READ(13,*)D23
	  READ(13,*)A33
	  READ(13,*)ALPHA33
	  READ(13,*)C33
	  READ(13,*)D33
	  READ(13,*)MASSX	  
	  CLOSE (13)
*    1=N, 2=X, 3=H
	  SPECIESMASS(1)=14.00307400443
      SPECIESMASS(2)=MASSX
	  SPECIESMASS(3)=1.00782503223
	
************************************************************************************************
*	INITIALIZATION OF RANDOM NUMBER GENERATOR's ISEED (MUST BE IN THE BEGINING OF PROGRAM)

	  CALL RANSI_2(ISEED)

***********************************************************************************
	  IF (INPUT.EQ.0) THEN
	   MARKER1 = 5*NN
	   MARKER2 = MARKER1 + 1
	   NMOLECULES = 5*NN+NCL
	   GOTO 41
	  END IF


      WRITE(26,*) 'Building an initial structure.'

*************************************************************************************************
********SPECIES1 LOOP  **************************************************************************
*   First part of list is a list of ammoniums.
*	THIS LOOP PLACES AMMONIUM IONS WITHIN A GIVEN BOX SIZE					*
*************************************************************************************************		
*************************************************************************************************
*
*	MARKER1 CORRESPONDS TO THE LAST HYDROGEN IN THE 
*       ARRAY BEFORE THE CHLORINES
*
	  J=1
	  REJECTS = 0
	  MARKER1 = 5*NN
	  
5	  IF (J.LE.MARKER1) THEN
	   CALL RANSR_2(RN,IVEC)
	   LOCALE(J,1) = SIZE * RN(IVEC)
	   CALL RANSR_2(RN,IVEC)					
	   LOCALE(J,2) = SIZE * RN (IVEC)
	   CALL RANSR_2(RN,IVEC)		
	   LOCALE(J,3) = SIZE * RN (IVEC)

*	***********************************************************************
*	ONLY ALLOWS PARTICLES WITH A CERTAIN SPACING (SPECIES1 IS ONLY PRESENT AT THIS POINT)	
*	BASED on the CsCl style lattice parameter
*	*************************************************************************

	   IF (J.NE.1) THEN
	    DO 20 K=1,J-1
		 X=LOCALE(J,1)-LOCALE(K,1)
		 Y=LOCALE(J,2)-LOCALE(K,2)
		 Z=LOCALE(J,3)-LOCALE(K,3)
		 DIST = SQRT (X**2 + Y**2 + Z**2)

*	DETERMINES IF ANY TWO AMMONIUMS ARE TOO CLOSE
		 IF ((DIST .LT. 6.33) .AND. (J .NE. 1)) THEN
		  REJECTS = REJECTS + 1
		  GOTO 	5
		 END IF

*	TOO MANY REJECTS (MORE THAN MAXREJECTS) MEANS BOX IS TOO SMALL
		 IF (REJECTS .GT. MAXREJECT) THEN
		  WRITE(26,*) 'TOO MANY AMMONIUM REJECTIONS'
		  WRITE(26,*) REJECTS
		  STOP			
		 ENDIF
 	
20	    CONTINUE
	   END IF

***********************************************************************************		
	   XX=LOCALE(J,1)
	   YY=LOCALE(J,2)
	   ZZ=LOCALE(J,3)

*	Subroutine tetrahedron builds a tetrahedron of hydrogens around nitrogen

	   CALL TETRAHEDRON (R,ISEED,DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,PHI,THETA) 

*	places hydrogens in locale array. XX is the x coordinate of central nitrogenetc.
*	DX1 is the distance in the X direction for the first hydrogen 
			
	   LOCALE(J+1,1)=XX+DX1
	   LOCALE(J+2,1)=XX+DX2
	   LOCALE(J+3,1)=XX+DX3
	   LOCALE(J+4,1)=XX+DX4
	   LOCALE(J+1,2)=YY+DY1
	   LOCALE(J+2,2)=YY+DY2
	   LOCALE(J+3,2)=YY+DY3
	   LOCALE(J+4,2)=YY+DY4
	   LOCALE(J+1,3)=ZZ+DZ1
	   LOCALE(J+2,3)=ZZ+DZ2
	   LOCALE(J+3,3)=ZZ+DZ3
       LOCALE(J+4,3)=ZZ+DZ4
	   J = J+5
	  END IF
	
 	  IF (J.LE.MARKER1) THEN
	   GOTO 5	
	  END IF
	  WRITE(26,*)'ammonium rejects',REJECTS

	  REJECTS = 0
	  MARKER2 = 5 * NN + 1

********************************************************************************
********END OF SPECIES 1 LOOP***************************************************
*******************************************************************************

********SPECIES2 LOOP *********************************************************
*   Second list is a list of halide anions.

30	  IF (J .LE. NATOM) THEN
	   CALL RANSR_2(RN,IVEC)
	   LOCALE(J,1) = SIZE*RN(IVEC)
	   CALL RANSR_2(RN,IVEC)	
	   LOCALE(J,2) = SIZE*RN(IVEC)
	   CALL RANSR_2(RN,IVEC)
	   LOCALE(J,3) = SIZE*RN(IVEC)

	   IF (J.NE.1) THEN
	    DO 40 K=1,J-1
		 X=LOCALE(J,1)-LOCALE(K,1)
		 Y=LOCALE(J,2)-LOCALE(K,2)
		 Z=LOCALE(J,3)-LOCALE(K,3)
		 DIST = SQRT (X**2 + Y**2 + Z**2)	
		 IF ((DIST .LT. 6.63) .AND. (K.LT.MARKER2)) THEN
		  REJECTS = REJECTS + 1
		  GOTO 	30
		 END IF
		 IF ((DIST .LT. 7.311) .AND. (K.GE.MARKER2)) THEN
		   REJECTS = REJECTS + 1
		   GOTO 	30
		 END IF
				
		 IF (REJECTS .GT. MAXREJECT) THEN
		  WRITE(26,*) 'TOO MANY ANION REJECTIONS'
		  WRITE(26,*) REJECTS
		  STOP			
		 END IF 	
40	    CONTINUE
	   END IF 
	   J = J+1
	  END IF
	
	  IF (J.LE.NATOM) THEN
       GOTO 30
	  END IF
	  WRITE(26,*)'Anion rejects',REJECTS

      WRITE(26,*)'Initial structure built'

41	  CALL ENERGY (U, LOCALE, MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)
	
	  KJ = U * 2625.49963948	! energy  in kj/mol using 2018 CODATA values
	  WRITE(26,*)'Initial energy is ',U, 'Eh or', KJ, 'KJ/mol'  
	
	  NMOLECULES = NN + NCL	
	
* I am initializing my flag for position change
	
	  DO 55  J=1, NMOLECULES			
	   LOCALE(J, 4) = 0
55	  END DO
		
***********************************************************************************************
*	PICK A MOLECULE AT RANDOM							      *
*											      *
***********************************************************************************************

      OPEN(20, file = TEMPSFILE)
      WRITE(20,*)'  N                NTHTEMP                 Energy(Hartree)             Energy(kJ/mole)'
      IF (MONTES.GT.0) WRITE(26,*)'Beginning annealing schedule.'
      IF (NTEETH.EQ.1) WRITE(26,*) 'Simple linear annealing chosen.'
      IF (NTEETH.GT.1) WRITE(26,*) 'Sawtooth linear annealing chosen.'
      IF (MAGSTEPPROB.GT.0.0) WRITE(26,*)'Magwalking translations.'
      IF (MAGROT.GT.0.0) WRITE(26,*)'Magwalking rotations.'
      TOOTHTOP(1)=TEMP1
      DO 667 I=2,NTEETH
       TOOTHTOP(I)=TOOTHTOP(I-1)*ALPHAUPPERDEC
667	  END DO        
	  
	  DO 668 I=1,NTEETH  
       TEMPKEL=TOOTHTOP(I)
       KBTEMP=KB*TEMPKEL
	   DELTEMP = TEMPKEL/DBLE(NTEMPS)         
       WRITE(26,*)'TOOTH #',I
       DO 666 NTHTEMP=1,NTEMPS+1
 	    COUNT =0
        NACCEPTS=0
        IF (NTHTEMP.EQ.NTEMPS+1) TEMPKEL=0.0 ! Set T=0 for last temp in tooth
        IF (NTHTEMP.EQ.NTEMPS+1) THEN
         MONTESTEPS=MONTES*MONTEMULTIPLIER
        ELSE
         MONTESTEPS=MONTES
        ENDIF
	    DO 990 M=1, MONTESTEPS
	     Call ransr_2(rn,ivec)
	     PICKED = INT(RN(IVEC)*(NMOLECULES))+1
	
*****TRANSLATION	
*	MAX STEP SIZE IN ONE CARTESIAN DIRECTION IS STEP
*       STEP=STEPSIZE if step is ordinary
*       otherwise STEP=10*STEPSIZE
*
	     CAll RANSR_2(RN,IVEC)
         IF (RN(IVEC).LT.MAGSTEPPROB) THEN
          STEP=STEPSIZE*10.0
         ELSE
          STEP=STEPSIZE
         ENDIF	

	     CALL RANSR_2(RN,IVEC)
	     XSTEP = STEP*(2.0*RN(IVEC)-1.0) ! see p. 119 Allen/Tildesley
	     CALL RANSR_2(RN,IVEC)
	     YSTEP = STEP*(2.0*RN(IVEC)-1.0)
	     CALL RANSR_2(RN,IVEC)
	     ZSTEP = STEP*(2.0*RN(IVEC)-1.0)
		 
**** Transfer individual atom information to temp variable	

	     DO 45 J=1,NATOM
		  TEMP(J,1)=LOCALE(J,1)
		  TEMP(J,2)=LOCALE(J,2)
		  TEMP(J,3)=LOCALE(J,3)
		  TEMP(J,4)=LOCALE(J,4)		
45	     CONTINUE
		 NSPOT = 1
		 CLSPOT = MARKER1+1
		 HSPOT = 5 
	
	     UO= 0.0

	     IF (PICKED.GT.NN) THEN
	
		  CLSPOT = MARKER1+PICKED-NN
		  TEMP(CLSPOT,4) = 1		! Set flag on for chloride 
*	Find potential energy between target atom and system before movement 
		  CALL ENERGY2 (UO,TEMP,MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  	ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)	

		  TEMP(CLSPOT,1) = LOCALE(CLSPOT,1) + XSTEP
		  TEMP(CLSPOT,2) = LOCALE(CLSPOT,2) + YSTEP
		  TEMP(CLSPOT,3) = LOCALE(CLSPOT,3) + ZSTEP
	     ELSE
		  NSPOT = 5*PICKED-4
		  TEMP(NSPOT,4) = 1		! set flag on for nitrogen
		  DO 76 J=NSPOT+1, NSPOT+4	!set flag on for hydrogens attached to nitrogen
		   TEMP(J,4) = 1
76	      CONTINUE
*	Find potential energy between target atom and system before movement 
		  CALL ENERGY2 (UO,TEMP,MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  		ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)	
		  TEMP(NSPOT,1) = LOCALE(NSPOT,1) + XSTEP
		  TEMP(NSPOT,2) = LOCALE(NSPOT,2) + YSTEP
		  TEMP(NSPOT,3) = LOCALE(NSPOT,3) + ZSTEP
	
		  DO 50 J=NSPOT+1,NSPOT+4
		   TEMP(J,1) = LOCALE(J,1) + XSTEP
		   TEMP(J,2) = LOCALE(J,2) + YSTEP
		   TEMP(J,3) = LOCALE(J,3) + ZSTEP	
50 		  CONTINUE

		  CALL DIFFERENCE (DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,TEMP,NSPOT)

		  CALL RANSR_2(RN,IVEC)
		
		  IF (RN(IVEC).GT.MAGROT) THEN
		   CALL ROTATE (DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,ISEED,MAXANGLE)
		  ELSE	
		   CALL ROTATE (DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,ISEED,PI)
		  END IF
		  XX=TEMP(NSPOT,1)
		  YY=TEMP(NSPOT,2)
		  ZZ=TEMP(NSPOT,3)
			
		  TEMP(NSPOT+1,1)=XX+DX1
		  TEMP(NSPOT+2,1)=XX+DX2
		  TEMP(NSPOT+3,1)=XX+DX3
		  TEMP(NSPOT+4,1)=XX+DX4
		  TEMP(NSPOT+1,2)=YY+DY1
		  TEMP(NSPOT+2,2)=YY+DY2
		  TEMP(NSPOT+3,2)=YY+DY3
		  TEMP(NSPOT+4,2)=YY+DY4
		  TEMP(NSPOT+1,3)=ZZ+DZ1
		  TEMP(NSPOT+2,3)=ZZ+DZ2
		  TEMP(NSPOT+3,3)=ZZ+DZ3
		  TEMP(NSPOT+4,3)=ZZ+DZ4
	     END IF


	     UNEWM = 0.0
	
*	Find energy between moved atom and system,
	
	     CALL ENERGY2 (UNEWM,TEMP,MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  	ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)
*  check for finite temperature below added in version 4.6
             IF (TEMPKEL.GT.0) THEN	
	        BOLTCOND = EXP(-(UNEWM-UO)/KBTEMP)
             ELSE
                BOLTCOND = 0.0D00
             END IF
	     CALL RANSR_2(RN,IVEC)
	     XSI = RN(IVEC)

	     LOCALE(CLSPOT,4)=0.0					! reset flag for Cl
	     LOCALE(NSPOT,4)=0.0					! reset flag  for N
	
	     DO 59 J=1,4
		  HSPOT=NSPOT +J
		  LOCALE(HSPOT,4)=0.0			! reset flag for H's 
59		 CONTINUE	

*** Energy comparison is only between before and after the moved

	     IF ((UNEWM.LT.UO).OR.(XSI.LT.BOLTCOND)) THEN	
		  LOCALE(CLSPOT,1)=TEMP(CLSPOT,1)
		  LOCALE(CLSPOT,2)=TEMP(CLSPOT,2)
		  LOCALE(CLSPOT,3)=TEMP(CLSPOT,3)	
		  LOCALE(NSPOT,1)=TEMP(NSPOT,1)
		  LOCALE(NSPOT,2)=TEMP(NSPOT,2)
		  LOCALE(NSPOT,3)=TEMP(NSPOT,3)
		  DO 60 J=1,4
		   HSPOT=NSPOT +J
		   LOCALE(HSPOT,1)=TEMP(HSPOT,1)
		   LOCALE(HSPOT,2)=TEMP(HSPOT,2)
		   LOCALE(HSPOT,3)=TEMP(HSPOT,3)	
60		  CONTINUE		

		  NACCEPTS=NACCEPTS+1
	     ENDIF
		 COUNT = COUNT +1
990 	CONTINUE

	    CALL ENERGY (U, LOCALE, MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     & 		ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)	
		KJ = U * 2625.49963948
		WRITE(26,*)'ACCEPTANCE RATIO (Fraction of moves accepted):'
        RATIO=REAL(NACCEPTS)/REAL(COUNT)
		WRITE(26,*)RATIO
 		WRITE(26,*)'temp K',TEMPKEL,'energy of final config:',U, ' Eh or ', KJ, 'KJ/mol'  
        COUNTTEMPS=COUNTTEMPS+1.0
        WRITE(20,*)COUNTTEMPS,TEMPKEL,U, KJ
	
*	OUTPUT NEW STRUCTURE TO XMOL FILE "movie.XYZ" (coords in angstroms)
	    IF (IMOVIE.NE.0) THEN  
*   Locate the center of mass
         CALL CENTER(LOCALE,XC,YC,ZC,MARKER1,NATOM,SPECIESMASS)		
		 WRITE(17,*)NATOM
		 WRITE(17,*)' ','temp K',TEMPKEL,'energy of final config:',U, ' Eh or ', KJ, 'KJ/mol'  
		 DO 106 J=1,MARKER1,5
		  WRITE(17,*)SPECIES(1),(LOCALE(J,1)-XC)*BTOA,(LOCALE(J,2)-YC)*BTOA,(LOCALE(J,3)-ZC)*BTOA
		  DO 101 K=J+1,J+4,1
		   WRITE(17,*)SPECIES(3),(LOCALE(K,1)-XC)*BTOA,(LOCALE(K,2)-YC)*BTOA,(LOCALE(K,3)-ZC)*BTOA
101		  CONTINUE
106 	 CONTINUE
		 DO 121 L=MARKER1+1,NATOM,1
		  WRITE(17,*)SPECIES(2),(LOCALE(L,1)-XC)*BTOA,(LOCALE(L,2)-YC)*BTOA,(LOCALE(L,3)-ZC)*BTOA
121		 CONTINUE			
        END IF
*   In version 4.3.2 this line was moved to here (after writing to movie.xyz)
        TEMPKEL=TEMPKEL-DELTEMP 

		
666	   CONTINUE

	   NTEMPS= NTEMPS + INCMORE    !This increases the number of cycles for the next teeth

	   CALL ENERGY (U, LOCALE, MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  		ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)	

*	OUTPUT NEW STRUCTURE TO XMOL FILE "FINAL.XYZ" (coords in angstroms)
	   OPEN(15, file = OUTFILE(I))
       TEMPKEL=TEMPKEL+DELTEMP
	   KJ = U * 2625.49963948    ! Find energy in Kj/mol
	   WRITE(15,*)NATOM
	   WRITE(15,*)' ','temp K',TEMPKEL,'energy of final config:',U, ' Eh or ', KJ, 'KJ/mol'  
	   DO 105 J=1,MARKER1,5
	    WRITE(15,*)SPECIES(1),(LOCALE(J,1)-XC)*BTOA,(LOCALE(J,2)-YC)*BTOA,(LOCALE(J,3)-ZC)*BTOA
	    DO 100 K=J+1,J+4,1
		 WRITE(15,*)SPECIES(3),(LOCALE(K,1)-XC)*BTOA,(LOCALE(K,2)-YC)*BTOA,(LOCALE(K,3)-ZC)*BTOA
100	    CONTINUE
105    CONTINUE

	   DO 120 L=MARKER1+1,NATOM,1
	    WRITE(15,*)SPECIES(2),(LOCALE(L,1)-XC)*BTOA,(LOCALE(L,2)-YC)*BTOA,(LOCALE(L,3)-ZC)*BTOA
120	   CONTINUE	
	   TEMPKEL=TEMPKEL+DELTEMP
       CLOSE(15)
668   CONTINUE
       
	  CALL ENERGY (U, LOCALE, MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  		ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)	
	
	  KJ = U * 2625.49963948
	  WRITE(26,*)'Energy of final configuration (Hartree)         ',U, ' Eh or ', KJ, 'KJ/mol'  
	  close(16)
	  close(20)
	  close(26)
	
	  END

************************************************************************************************************************
************************************************************************************************************************
*	The Subroutines Begin Here
************************************************************************************************************************
************************************************************************************************************************

      SUBROUTINE TETRAHEDRON (R,ISEED,DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,PHI,THETA)

********BUILDS A TETRAHEDRON AROUND THE CENTRAL ATOM WITH A RANDOM ROTATION*********************************************
*	CALLS ROTATE TO ACCOMPLISH RANDOM ROTATION *********************************************************************

	  DOUBLE PRECISION PI
	  DOUBLE PRECISION DX4,DX3,DX2,DX1
	  DOUBLE PRECISION DY4,DY3,DY2,DY1
	  DOUBLE PRECISION DZ4,DZ3,DZ2,DZ1
	  DOUBLE PRECISION R
	  DOUBLE PRECISION PHI
	  DOUBLE PRECISION THETA, THETA2
	  INTEGER ISEED

	  PI = 3.1415927
	  PHI = 0.0
	  THETA = 0.0	
	
*	SUBSTITUENT 1
	  DX1=R*DSIN(THETA)*DCOS(PHI)
	  DY1=R*DSIN(THETA)*DSIN(PHI)
	  DZ1=R*DCOS(THETA)
*	SUBSTITUENT 2
	  THETA2 = THETA + 1.9106329
	  DX2=R*DSIN(THETA2)*DCOS(PHI)
	  DY2=R*DSIN(THETA2)*DSIN(PHI)
	  DZ2=R*DCOS(THETA2)
*	SUBSTITUENT 3
	  PHI = PHI + 2*PI/3
 	  DX3=R*DSIN(THETA2)*DCOS(PHI)
	  DY3=R*DSIN(THETA2)*DSIN(PHI)
	  DZ3=R*DCOS(THETA2)
*	SUBSTITUENT 4
	  PHI = PHI + 2*PI/3
	  DX4=R*DSIN(THETA2)*DCOS(PHI)
	  DY4=R*DSIN(THETA2)*DSIN(PHI)
	  DZ4=R*DCOS(THETA2)

	  CALL ROTATE(DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,ISEED,PI) 
	  CALL ROTATE(DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,ISEED,PI)
	  CALL ROTATE(DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,ISEED,PI)

	  RETURN
	  END


*********************************************************************************************
*	Difference Subroutine - Determines the x,y,and z dispalcements of hydrogen atoms
********************************************************************************************
	  SUBROUTINE DIFFERENCE (DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,TEMPD,NSPOT)
	  DOUBLE PRECISION TEMPD(2000,3)
	  DOUBLE PRECISION DX4,DX3,DX2,DX1
	  DOUBLE PRECISION DY4,DY3,DY2,DY1
	  DOUBLE PRECISION DZ4,DZ3,DZ2,DZ1
	  INTEGER NSPOT	
	
	  DX1 = (TEMPD(NSPOT+1,1)-TEMPD(NSPOT,1))
	  DX2 = (TEMPD(NSPOT+2,1)-TEMPD(NSPOT,1))
	  DX3 = (TEMPD(NSPOT+3,1)-TEMPD(NSPOT,1))
	  DX4 = (TEMPD(NSPOT+4,1)-TEMPD(NSPOT,1))

	  DY1 = (TEMPD(NSPOT+1,2)-TEMPD(NSPOT,2))
	  DY2 = (TEMPD(NSPOT+2,2)-TEMPD(NSPOT,2))
	  DY3 = (TEMPD(NSPOT+3,2)-TEMPD(NSPOT,2))
	  DY4 = (TEMPD(NSPOT+4,2)-TEMPD(NSPOT,2))

	  DZ1 = (TEMPD(NSPOT+1,3)-TEMPD(NSPOT,3))
	  DZ2 = (TEMPD(NSPOT+2,3)-TEMPD(NSPOT,3))
	  DZ3 = (TEMPD(NSPOT+3,3)-TEMPD(NSPOT,3))
	  DZ4 = (TEMPD(NSPOT+4,3)-TEMPD(NSPOT,3))
		
	  RETURN	
	  END


***********************************************************************************************************
*	ROTATES HYDROGEN ATOMS AROUND THEIR CORRESPONDING NITROGEN
**************************************************************************************************
	  SUBROUTINE ROTATE (DX1,DX2,DX3,DX4,DY1,DY2,DY3,DY4,DZ1,DZ2,DZ3,DZ4,ISEED,MAXANGLE)
	
	  DOUBLE PRECISION DX4,DX3,DX2,DX1
	  DOUBLE PRECISION DY4,DY3,DY2,DY1
	  DOUBLE PRECISION DZ4,DZ3,DZ2,DZ1
	  DOUBLE PRECISION DX4P,DX3P,DX2P,DX1P
	  DOUBLE PRECISION DY4P,DY3P,DY2P,DY1P
	  DOUBLE PRECISION DZ4P,DZ3P,DZ2P,DZ1P
	  DOUBLE PRECISION GAMMA, COSG,SING
	  DOUBLE PRECISION PI,MAXANGLE
	  INTEGER IAXIS
	  INTEGER ISEED
*******	variables for nightran2.f ***********************************************	
	  PARAMETER (IVEC=1)
	  REAL*8 RN(IVEC)
********************************************************************************

	  PI = 3.1415927 
*	Chooses an axis (x y or z) around which to rotate
	
	  CALL RANSR_2(RN,IVEC)
	  IAXIS = INT(3*RN(IVEC))

	  CALL RANSR_2(RN,IVEC)
	  GAMMA = MAXANGLE*2*(RN(IVEC)-.5)
	
 	  COSG = DCOS(GAMMA)
	  SING = DSIN(GAMMA)

* 	rotation around x-axis, calculates new coords, DY1P=new distance of 
*	hydrogen 1 from nitrogen in y-direction, etc.

	  IF (IAXIS.EQ.0) THEN
	   DX1P=DX1
	   DX2P=DX2
	   DX3P=DX3
	   DX4P=DX4
	   DY1P=COSG*DY1+SING*DZ1
	   DY2P=COSG*DY2+SING*DZ2
	   DY3P=COSG*DY3+SING*DZ3
	   DY4P=COSG*DY4+SING*DZ4
	   DZ1P=COSG*DZ1-SING*DY1
	   DZ2P=COSG*DZ2-SING*DY2
	   DZ3P=COSG*DZ3-SING*DY3
	   DZ4P=COSG*DZ4-SING*DY4

*	rotation around y axis
 
	  ELSE IF (IAXIS.EQ.1) THEN
	   DX1P=COSG*DX1-SING*DZ1
	   DX2P=COSG*DX2-SING*DZ2
	   DX3P=COSG*DX3-SING*DZ3
	   DX4P=COSG*DX4-SING*DZ4
	   DY1P=DY1
	   DY2P=DY2
	   DY3P=DY3
	   DY4P=DY4
	   DZ1P=COSG*DZ1+SING*DX1
	   DZ2P=COSG*DZ2+SING*DX2
	   DZ3P=COSG*DZ3+SING*DX3
	   DZ4P=COSG*DZ4+SING*DX4
	   
*	rotation around z-axis
		
	  ELSE 
	   DX1P=COSG*DX1+SING*DY1
	   DX2P=COSG*DX2+SING*DY2
	   DX3P=COSG*DX3+SING*DY3
	   DX4P=COSG*DX4+SING*DY4
	   DY1P=COSG*DY1-SING*DX1
	   DY2P=COSG*DY2-SING*DX2
	   DY3P=COSG*DY3-SING*DX3
	   DY4P=COSG*DY4-SING*DX4
	   DZ1P=DZ1
	   DZ2P=DZ2
	   DZ3P=DZ3
	   DZ4P=DZ4
	  ENDIF
	
	  DX1=DX1P
	  DX2=DX2P
	  DX3=DX3P
	  DX4=DX4P		
	  DY1=DY1P
	  DY2=DY2P
	  DY3=DY3P
	  DY4=DY4P
	  DZ1=DZ1P
	  DZ2=DZ2P
	  DZ3=DZ3P
	  DZ4=DZ4P

      RETURN
	  END

*************************************************************************************************
*************************************************************************************************
*	ENERGY DETERMINATION SUBROUTINE for entire system
*
*
*************************************************************************************************
*************************************************************************************************
	  SUBROUTINE ENERGY (TU,LOCALE,MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  		ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)
	  DOUBLE PRECISION U, UNEW, Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33 
	  DOUBLE PRECISION ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33
	  DOUBLE PRECISION XC, YC, ZC
	  INTEGER MARKER1, NATOM,count
	  DOUBLE PRECISION LOCALE(2000,3), DIST, R, RC
	  DOUBLE PRECISION TU,RU,CU
C	  DOUBLE PRECISION R0, THETA0, kNH, kHH, THETAKM
	  DOUBLE PRECISION DIFF(400,4,3), RCP(400,4),DP(400,4,2:4)
	  DOUBLE PRECISION SPECIESMASS(3)
			
*	R is distance of an individual atom from the center of mass
	
C	CU is the constraining potential, and TU is the total
	
	  RU = 0.0
	  TU = 0.0
	  CU = 0.0 
	  DIST = 0.0
	  COUNT = 0
C	  R0 = 1.9467	! in bohr
C	  THETA0 = 1.9106
C	  KNH =.351	!hartree/(bohr)**2
C	  KHH = 0.137	!hartree	

	  CALL CENTER(LOCALE,XC,YC,ZC,MARKER1,NATOM,SPECIESMASS)

	  DO 10 J=1,NATOM,1
	   R=SQRT((LOCALE(J,1)-XC)**2+(LOCALE(J,2)-YC)**2+(LOCALE(J,3)-ZC)**2)
	   CU=CU+(R/RC)**20	
10 	  CONTINUE
	
*	N-N INTERACTION  
	  DO 200 J=1,MARKER1,5
	   DO 150 K=J+5,MARKER1,5
	    DIST =SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		RU = RU + A11*EXP(-ALPHA11*DIST) + D11/DIST**12 + Q1**2/DIST - C11/DIST**6		
150    CONTINUE
200   CONTINUE
	
*	CL-CL INTERACTION
	  DO 250 J=MARKER1+1,NATOM
	   DO 225 K=J+1,NATOM
		DIST = SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		RU = RU + A22*EXP(-ALPHA22*DIST) + D22/DIST**12 + Q2**2/DIST - C22/DIST**6
225	   CONTINUE
250	  CONTINUE

*	H-H INTERACTION - ignores h-h attraction w/in one ammonium ion (treats as rigid tetrahedron)
	  DO 350 J=2,MARKER1-3,5
	   DO 325 I=J+5,MARKER1,5
	    DO 300 K=I,I+3
		 DIST = SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		 RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		 DIST = SQRT((LOCALE(J+1,1)-LOCALE(K,1))**2+(LOCALE(J+1,2)-LOCALE(K,2))**2+(LOCALE(J+1,3)-LOCALE(K,3))**2)
		 RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		 DIST = SQRT((LOCALE(J+2,1)-LOCALE(K,1))**2+(LOCALE(J+2,2)-LOCALE(K,2))**2+(LOCALE(J+2,3)-LOCALE(K,3))**2)
		 RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		 DIST = SQRT((LOCALE(J+3,1)-LOCALE(K,1))**2+(LOCALE(J+3,2)-LOCALE(K,2))**2+(LOCALE(J+3,3)-LOCALE(K,3))**2)
		 RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
300	    CONTINUE
325	   CONTINUE
350	  CONTINUE


*	N-CL INTERACTION
	  DO 476 J=1,MARKER1,5
	   DO 451 K=MARKER1+1,NATOM
		DIST = SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		RU = RU + A12*EXP(-ALPHA12*DIST) + D12/DIST**12 + Q2*Q1/DIST - C12/DIST**6
451	   CONTINUE 
476	  CONTINUE

*	N-H INTERACTION - ignores n-h interaction w/in ammonium ion (treats as
*	rigid tetrahedron)
	  DO 600 J = 1,MARKER1-4,5
	   DO 550 K = J+6,MARKER1,5
	    DO 500 L=K,K+3
		 DIST = SQRT((LOCALE(J,1)-LOCALE(L,1))**2+(LOCALE(J,2)-LOCALE(L,2))**2+(LOCALE(J,3)-LOCALE(L,3))**2)		
		 RU = RU + A13*EXP(-ALPHA13*DIST) + D13/DIST**12 + Q3*Q1/DIST - C13/DIST**6		
500 	CONTINUE
550	   CONTINUE 
600	  CONTINUE

	  DO 620 J=MARKER1-4,1,-5
	   DO 615 K=J-4,1,-5
	    DO 605 L=K, K+3
		 DIST = SQRT((LOCALE(J,1)-LOCALE(L,1))**2+(LOCALE(J,2)-LOCALE(L,2))**2+(LOCALE(J,3)-LOCALE(L,3))**2)		
		 RU = RU + A13*EXP(-ALPHA13*DIST) + D13/DIST**12 + Q3*Q1/DIST - C13/DIST**6	
605	    CONTINUE
615	   CONTINUE
620	  CONTINUE

*	H-X INTERACTION
	  DO 700 J=2,MARKER1,5
	   DO 650 K=J,J+3
	    DO 625 L=MARKER1+1,NATOM	
		 DIST = SQRT((LOCALE(K,1)-LOCALE(L,1))**2+(LOCALE(K,2)-LOCALE(L,2))**2+(LOCALE(K,3)-LOCALE(L,3))**2)		
		 RU = RU + A23*EXP(-ALPHA23*DIST) + D23/DIST**12 + Q3*Q2/DIST - C23/DIST**6
625	    CONTINUE
650    CONTINUE
700	  CONTINUE

		
	  TU = RU + CU

	  RETURN
	  END
	
*************************************************************************************************
*************************************************************************************************
*	ENERGY DETERMINATION SUBROUTINE For only specific atom and sytem
*
*
*************************************************************************************************
*************************************************************************************************
	  SUBROUTINE ENERGY2 (TU,LOCALE,MARKER1, NATOM,Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33, 
     &  		ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33,RC,CU,RU,SPECIESMASS)
	  DOUBLE PRECISION U, UNEW, Q1,Q2,Q3,A11,A12,A13,A22,A23,A33,ALPHA11,ALPHA22,ALPHA33 
	  DOUBLE PRECISION ALPHA12,ALPHA13,ALPHA23,C11,C12,C13,C22,C23,C33,D11,D12,D13,D22,D23,D33
	  DOUBLE PRECISION XC, YC, ZC
	  INTEGER MARKER1, NATOM,count
	  DOUBLE PRECISION LOCALE(2000,4), DIST, R, RC
	  DOUBLE PRECISION TU,RU,CU
C	  DOUBLE PRECISION R0, THETA0, kNH, kHH, THETAKM
	  DOUBLE PRECISION DIFF(400,4,3), RCP(400,4),DP(400,4,2:4)
	  DOUBLE PRECISION SPECIESMASS(3)
		
*	R is distance of an individual atom from the center of mass
	
C	CU is the constraining potential, and TU is the total
	
	  RU = 0.0
	  TU = 0.0
	  CU = 0.0
	
	  DIST = 0.0
	  COUNT = 0
C	  R0 = 1.9467	! in bohr
C	  THETA0 = 1.9106
C	  KNH =.351	!hartree/(bohr)**2
C	  KHH = 0.137	!hartree	

	  CALL CENTER(LOCALE,XC,YC,ZC,MARKER1,NATOM,SPECIESMASS)

	  DO 10 J=1,NATOM,1
	   R=SQRT((LOCALE(J,1)-XC)**2+(LOCALE(J,2)-YC)**2+(LOCALE(J,3)-ZC)**2)
	   CU=CU+(R/RC)**20	
10 	  CONTINUE
	
*	N-N INTERACTION  
	  DO 200 J=1,MARKER1,5
	   DO 150 K=J+5,MARKER1,5
*Evaluate only if atoms has moved relative to other atom or if it has been targeted	
	    IF(LOCALE(J,4).NE. LOCALE(K,4)) THEN  
		 DIST =SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		 RU = RU + A11*EXP(-ALPHA11*DIST) + D11/DIST**12 + Q1**2/DIST - C11/DIST**6
		END IF
150    CONTINUE
200   CONTINUE
	
*	CL-CL INTERACTION
	  DO 250 J=MARKER1+1,NATOM
	   DO 225 K=J+1,NATOM
*Evaluate only if atoms has moved relative to other atoms or if it has been targeted	
		IF(LOCALE(J,4).NE. LOCALE(K,4)) THEN 
		 DIST = SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		 RU = RU + A22*EXP(-ALPHA22*DIST) + D22/DIST**12 + Q2**2/DIST - C22/DIST**6
		END IF	
225	   CONTINUE
250	  CONTINUE

*	H-H INTERACTION - ignores h-h attraction w/in one ammonium ion (treats as rigid tetrahedron)
		
	  DO 350 J=2,MARKER1-3,5
	   DO 325 I=J+5,MARKER1,5
	    DO 300 K=I,I+3
*Evaluate only if atoms has moved relative to other atoms or if it has been targeted	
		 IF(LOCALE(J,4).NE. LOCALE(K,4)) THEN 
		  DIST = SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		  RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		  DIST = SQRT((LOCALE(J+1,1)-LOCALE(K,1))**2+(LOCALE(J+1,2)-LOCALE(K,2))**2+(LOCALE(J+1,3)-LOCALE(K,3))**2)
		  RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		  DIST = SQRT((LOCALE(J+2,1)-LOCALE(K,1))**2+(LOCALE(J+2,2)-LOCALE(K,2))**2+(LOCALE(J+2,3)-LOCALE(K,3))**2)
		  RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		  DIST = SQRT((LOCALE(J+3,1)-LOCALE(K,1))**2+(LOCALE(J+3,2)-LOCALE(K,2))**2+(LOCALE(J+3,3)-LOCALE(K,3))**2)
		  RU = RU + A33*EXP(-ALPHA33*DIST) + D33/DIST**12 + Q3**2/DIST - C33/DIST**6
		 END IF
300	    CONTINUE
325	   CONTINUE
350	  CONTINUE

*	N-CL INTERACTION
	  DO 475 J=1,MARKER1,5
	   DO 450 K=MARKER1+1,NATOM
*Evaluate only if atoms has moved relative to other atoms or if it has been targeted	
		IF(LOCALE(J,4).NE. LOCALE(K,4)) THEN 
		 DIST = SQRT((LOCALE(J,1)-LOCALE(K,1))**2+(LOCALE(J,2)-LOCALE(K,2))**2+(LOCALE(J,3)-LOCALE(K,3))**2)
		 RU = RU + A12*EXP(-ALPHA12*DIST) + D12/DIST**12 + Q2*Q1/DIST - C12/DIST**6
		END IF
450	   CONTINUE 
475	  CONTINUE

*	N-H INTERACTION - ignores n-h interaction w/in ammonium ion (treats as
*	rigid tetrahedron)

	  DO 601 J = 1,MARKER1-4,5
	   DO 551 K = J+6,MARKER1,5
	    DO 501 L=K,K+3
*Evaluate only if atoms has moved relative to other atoms or if it has been targeted	
		 IF(LOCALE(J,4).NE. LOCALE(L,4)) THEN 
		  DIST = SQRT((LOCALE(J,1)-LOCALE(L,1))**2+(LOCALE(J,2)-LOCALE(L,2))**2+(LOCALE(J,3)-LOCALE(L,3))**2)		
		  RU = RU + A13*EXP(-ALPHA13*DIST) + D13/DIST**12 + Q3*Q1/DIST - C13/DIST**6
		 END IF
501 	CONTINUE
551	   CONTINUE 
601	  CONTINUE

	  DO 620 J=MARKER1-4,1,-5
	   DO 615 K=J-4,1,-5
	    DO 605 L=K, K+3
*Evaluate only if atoms has moved relative to other atoms or if it has been targeted	
		 IF(LOCALE(J,4).NE. LOCALE(L,4)) THEN 
		  DIST = SQRT((LOCALE(J,1)-LOCALE(L,1))**2+(LOCALE(J,2)-LOCALE(L,2))**2+(LOCALE(J,3)-LOCALE(L,3))**2)		
		  RU = RU + A13*EXP(-ALPHA13*DIST) + D13/DIST**12 + Q3*Q1/DIST - C13/DIST**6
		 END IF
605	    CONTINUE
615	   CONTINUE
620	  CONTINUE


*	H-CL INTERACTION
	  DO 700 J=2,MARKER1,5
	   DO 650 K=J,J+3
	    DO 625 L=MARKER1+1,NATOM
*Evaluate only if atoms has moved relative to other atoms or if it has been targeted	
		 IF(LOCALE(K,4).NE. LOCALE(L,4)) THEN 
		  DIST = SQRT((LOCALE(K,1)-LOCALE(L,1))**2+(LOCALE(K,2)-LOCALE(L,2))**2+(LOCALE(K,3)-LOCALE(L,3))**2)		
		  RU = RU + A23*EXP(-ALPHA23*DIST) + D23/DIST**12 + Q3*Q2/DIST - C23/DIST**6
		 END IF
625		CONTINUE
650    CONTINUE
700	  CONTINUE

	  TU = RU + CU

	  RETURN
	  END
		
***************************************************************************************************************************
*	Subroutine to determine the x,y,and z coordinates of the center of mass of the cluster

	  SUBROUTINE CENTER (LOCALE,XC,YC,ZC,MARKER1,NATOM,SPECIESMASS)
	  DOUBLE PRECISION LOCALE (2000,3)
	  DOUBLE PRECISION XC,YC,ZC
	  DOUBLE PRECISION MASS
	  DOUBLE PRECISION XMASS,YMASS,ZMASS
	  DOUBLE PRECISION SPECIESMASS(3)
	  INTEGER MARKER1,NATOM
	  MASS=0.0
	  XMASS=0.0
	  YMASS=0.0
	  ZMASS=0.0
	  XC = 0.0
	  YC = 0.0
	  ZC = 0.0

! N 
	  DO 10 J=1,MARKER1-4,5
	   MASS = MASS + SPECIESMASS(1)
	   XMASS = XMASS + LOCALE(J,1)*SPECIESMASS(1)
	   YMASS = YMASS + LOCALE(J,2)*SPECIESMASS(1)
	   ZMASS = ZMASS + LOCALE(J,3)*SPECIESMASS(1)
10	  CONTINUE
! X
	  DO 20 J=MARKER1+1,NATOM,1
	   MASS = MASS + SPECIESMASS(2)
	   XMASS = XMASS + LOCALE(J,1)*SPECIESMASS(2)
	   YMASS = YMASS + LOCALE(J,2)*SPECIESMASS(2)
	   ZMASS = ZMASS + LOCALE(J,3)*SPECIESMASS(2)
20 	  CONTINUE	
! H
	  DO 40 J=2,MARKER1-3,5
	   DO 30 K=J,J+3,1
		MASS = MASS + SPECIESMASS(3)
		XMASS = XMASS + LOCALE(K,1)*SPECIESMASS(3)
		YMASS = YMASS + LOCALE(K,2)*SPECIESMASS(3)
		ZMASS = ZMASS + LOCALE(K,3)*SPECIESMASS(3)		
30	   CONTINUE
40 	  CONTINUE

	  XC = XMASS/MASS
	  YC = YMASS/MASS
	  ZC = ZMASS/MASS

	  RETURN
	  END	
		
